@@ -1,4 +1,5 @@
-/* This is a generated file, edit the .stub.php file instead. */
+/* This is a generated file, edit the .stub.php file instead.
+ * Stub hash: 01265f9c7567c4f73318f591c0b444a8b4fbcfa1 */
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_zip_open, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, filename, IS_STRING, 0)
@@ -15,11 +16,11 @@ ZEND_END_ARG_INFO()
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_zip_entry_open, 0, 2, _IS_BOOL, 0)
 	ZEND_ARG_INFO(0, zip_dp)
 	ZEND_ARG_INFO(0, zip_entry)
-	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, mode, IS_STRING, 0, "\'rb\'")
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, mode, IS_STRING, 0, "\"rb\"")
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_zip_entry_close, 0, 1, _IS_BOOL, 0)
-	ZEND_ARG_INFO(0, zip_ent)
+	ZEND_ARG_INFO(0, zip_entry)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_MASK_EX(arginfo_zip_entry_read, 0, 1, MAY_BE_STRING|MAY_BE_FALSE)
@@ -55,6 +56,9 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_class_ZipArchive_getStatusString arginfo_class_ZipArchive_close
 
+ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_class_ZipArchive_clearError, 0, 0, IS_VOID, 0)
+ZEND_END_ARG_INFO()
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_addEmptyDir, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, dirname, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, flags, IS_LONG, 0, "0")
@@ -76,7 +80,7 @@ ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_replaceFile, 0, 0, 2)
 	ZEND_ARG_TYPE_INFO(0, filepath, IS_STRING, 0)
-	ZEND_ARG_TYPE_INFO(0, index, IS_STRING, 0)
+	ZEND_ARG_TYPE_INFO(0, index, IS_LONG, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, start, IS_LONG, 0, "0")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, length, IS_LONG, 0, "0")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, flags, IS_LONG, 0, "0")
@@ -156,11 +160,11 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_deleteName, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, name, IS_STRING, 0)
 ZEND_END_ARG_INFO()
 
-#define arginfo_class_ZipArchive_statName arginfo_class_ZipArchive_open
+#define arginfo_class_ZipArchive_statName arginfo_class_ZipArchive_getCommentName
 
 #define arginfo_class_ZipArchive_statIndex arginfo_class_ZipArchive_getCommentIndex
 
-#define arginfo_class_ZipArchive_locateName arginfo_class_ZipArchive_open
+#define arginfo_class_ZipArchive_locateName arginfo_class_ZipArchive_getCommentName
 
 #define arginfo_class_ZipArchive_getNameIndex arginfo_class_ZipArchive_getCommentIndex
 
@@ -174,11 +178,11 @@ ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_extractTo, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO(0, pathto, IS_STRING, 0)
-	ZEND_ARG_INFO_WITH_DEFAULT_VALUE(0, files, "null")
+	ZEND_ARG_TYPE_MASK(0, files, MAY_BE_ARRAY|MAY_BE_STRING|MAY_BE_NULL, "null")
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_getFromName, 0, 0, 1)
-	ZEND_ARG_TYPE_INFO(0, entryname, IS_STRING, 0)
+	ZEND_ARG_TYPE_INFO(0, name, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, len, IS_LONG, 0, "0")
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, flags, IS_LONG, 0, "0")
 ZEND_END_ARG_INFO()
@@ -189,9 +193,11 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_getFromIndex, 0, 0, 1)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, flags, IS_LONG, 0, "0")
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_getStream, 0, 0, 1)
-	ZEND_ARG_TYPE_INFO(0, entryname, IS_STRING, 0)
-ZEND_END_ARG_INFO()
+#define arginfo_class_ZipArchive_getStreamIndex arginfo_class_ZipArchive_getCommentIndex
+
+#define arginfo_class_ZipArchive_getStreamName arginfo_class_ZipArchive_getCommentName
+
+#define arginfo_class_ZipArchive_getStream arginfo_class_ZipArchive_deleteName
 
 #if defined(ZIP_OPSYS_DEFAULT)
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_ZipArchive_setExternalAttributesName, 0, 0, 3)
@@ -271,9 +277,9 @@ ZEND_END_ARG_INFO()
 #endif
 
 #if defined(HAVE_METHOD_SUPPORTED)
-ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_class_ZipArchive_isCompressionMethodSupported, 0, 2, _IS_BOOL, 0)
+ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_class_ZipArchive_isCompressionMethodSupported, 0, 1, _IS_BOOL, 0)
 	ZEND_ARG_TYPE_INFO(0, method, IS_LONG, 0)
-	ZEND_ARG_TYPE_INFO(0, enc, _IS_BOOL, 0)
+	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, enc, _IS_BOOL, 0, "true")
 ZEND_END_ARG_INFO()
 #endif
 
@@ -297,6 +303,7 @@ ZEND_METHOD(ZipArchive, setPassword);
 ZEND_METHOD(ZipArchive, close);
 ZEND_METHOD(ZipArchive, count);
 ZEND_METHOD(ZipArchive, getStatusString);
+ZEND_METHOD(ZipArchive, clearError);
 ZEND_METHOD(ZipArchive, addEmptyDir);
 ZEND_METHOD(ZipArchive, addFromString);
 ZEND_METHOD(ZipArchive, addFile);
@@ -330,6 +337,8 @@ ZEND_METHOD(ZipArchive, unchangeName);
 ZEND_METHOD(ZipArchive, extractTo);
 ZEND_METHOD(ZipArchive, getFromName);
 ZEND_METHOD(ZipArchive, getFromIndex);
+ZEND_METHOD(ZipArchive, getStreamIndex);
+ZEND_METHOD(ZipArchive, getStreamName);
 ZEND_METHOD(ZipArchive, getStream);
 #if defined(ZIP_OPSYS_DEFAULT)
 ZEND_METHOD(ZipArchive, setExternalAttributesName);
@@ -366,16 +375,16 @@ ZEND_METHOD(ZipArchive, isEncryptionMethodSupported);
 
 
 static const zend_function_entry ext_functions[] = {
-	ZEND_FE(zip_open, arginfo_zip_open)
-	ZEND_FE(zip_close, arginfo_zip_close)
-	ZEND_FE(zip_read, arginfo_zip_read)
-	ZEND_FE(zip_entry_open, arginfo_zip_entry_open)
-	ZEND_FE(zip_entry_close, arginfo_zip_entry_close)
-	ZEND_FE(zip_entry_read, arginfo_zip_entry_read)
-	ZEND_FE(zip_entry_name, arginfo_zip_entry_name)
-	ZEND_FE(zip_entry_compressedsize, arginfo_zip_entry_compressedsize)
-	ZEND_FE(zip_entry_filesize, arginfo_zip_entry_filesize)
-	ZEND_FE(zip_entry_compressionmethod, arginfo_zip_entry_compressionmethod)
+	ZEND_DEP_FE(zip_open, arginfo_zip_open)
+	ZEND_DEP_FE(zip_close, arginfo_zip_close)
+	ZEND_DEP_FE(zip_read, arginfo_zip_read)
+	ZEND_DEP_FE(zip_entry_open, arginfo_zip_entry_open)
+	ZEND_DEP_FE(zip_entry_close, arginfo_zip_entry_close)
+	ZEND_DEP_FE(zip_entry_read, arginfo_zip_entry_read)
+	ZEND_DEP_FE(zip_entry_name, arginfo_zip_entry_name)
+	ZEND_DEP_FE(zip_entry_compressedsize, arginfo_zip_entry_compressedsize)
+	ZEND_DEP_FE(zip_entry_filesize, arginfo_zip_entry_filesize)
+	ZEND_DEP_FE(zip_entry_compressionmethod, arginfo_zip_entry_compressionmethod)
 	ZEND_FE_END
 };
 
@@ -386,6 +395,7 @@ static const zend_function_entry class_ZipArchive_methods[] = {
 	ZEND_ME(ZipArchive, close, arginfo_class_ZipArchive_close, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, count, arginfo_class_ZipArchive_count, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, getStatusString, arginfo_class_ZipArchive_getStatusString, ZEND_ACC_PUBLIC)
+	ZEND_ME(ZipArchive, clearError, arginfo_class_ZipArchive_clearError, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, addEmptyDir, arginfo_class_ZipArchive_addEmptyDir, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, addFromString, arginfo_class_ZipArchive_addFromString, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, addFile, arginfo_class_ZipArchive_addFile, ZEND_ACC_PUBLIC)
@@ -419,6 +429,8 @@ static const zend_function_entry class_ZipArchive_methods[] = {
 	ZEND_ME(ZipArchive, extractTo, arginfo_class_ZipArchive_extractTo, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, getFromName, arginfo_class_ZipArchive_getFromName, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, getFromIndex, arginfo_class_ZipArchive_getFromIndex, ZEND_ACC_PUBLIC)
+	ZEND_ME(ZipArchive, getStreamIndex, arginfo_class_ZipArchive_getStreamIndex, ZEND_ACC_PUBLIC)
+	ZEND_ME(ZipArchive, getStreamName, arginfo_class_ZipArchive_getStreamName, ZEND_ACC_PUBLIC)
 	ZEND_ME(ZipArchive, getStream, arginfo_class_ZipArchive_getStream, ZEND_ACC_PUBLIC)
 #if defined(ZIP_OPSYS_DEFAULT)
 	ZEND_ME(ZipArchive, setExternalAttributesName, arginfo_class_ZipArchive_setExternalAttributesName, ZEND_ACC_PUBLIC)
